@@ -7,6 +7,7 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
+	"log/slog"
 	"net/http"
 	"net/url"
 	"os"
@@ -15,7 +16,7 @@ import (
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config/data"
-	"github.com/rs/zerolog/log"
+	"github.com/derailed/k9s/internal/slogs"
 )
 
 // K9s tracks K9s configuration options.
@@ -26,6 +27,7 @@ type K9s struct {
 	MaxConnRetry        int        `json:"maxConnRetry" yaml:"maxConnRetry"`
 	ReadOnly            bool       `json:"readOnly" yaml:"readOnly"`
 	NoExitOnCtrlC       bool       `json:"noExitOnCtrlC" yaml:"noExitOnCtrlC"`
+	PortForwardAddress  string     `yaml:"portForwardAddress"`
 	UI                  UI         `json:"ui" yaml:"ui"`
 	SkipLatestRevCheck  bool       `json:"skipLatestRevCheck" yaml:"skipLatestRevCheck"`
 	DisablePodCounting  bool       `json:"disablePodCounting" yaml:"disablePodCounting"`
@@ -46,24 +48,40 @@ type K9s struct {
 	conn                client.Connection
 	ks                  data.KubeSettings
 	mx                  sync.RWMutex
+	contextSwitch       bool
 }
 
 // NewK9s create a new K9s configuration.
 func NewK9s(conn client.Connection, ks data.KubeSettings) *K9s {
 	return &K9s{
-		RefreshRate:   defaultRefreshRate,
-		MaxConnRetry:  defaultMaxConnRetry,
-		ScreenDumpDir: AppDumpsDir,
-		Logger:        NewLogger(),
-		Thresholds:    NewThreshold(),
-		ShellPod:      NewShellPod(),
-		ImageScans:    NewImageScans(),
-		dir:           data.NewDir(AppContextsDir),
-		conn:          conn,
-		ks:            ks,
+		RefreshRate:        defaultRefreshRate,
+		MaxConnRetry:       defaultMaxConnRetry,
+		ScreenDumpDir:      AppDumpsDir,
+		Logger:             NewLogger(),
+		Thresholds:         NewThreshold(),
+		PortForwardAddress: defaultPFAddress(),
+		ShellPod:           NewShellPod(),
+		ImageScans:         NewImageScans(),
+		dir:                data.NewDir(AppContextsDir),
+		conn:               conn,
+		ks:                 ks,
 	}
 }
 
+func (k *K9s) ToggleContextSwitch(b bool) {
+	k.mx.Lock()
+	defer k.mx.Unlock()
+
+	k.contextSwitch = b
+}
+
+func (k *K9s) getContextSwitch() bool {
+	k.mx.Lock()
+	defer k.mx.Unlock()
+
+	return k.contextSwitch
+}
+
 func (k *K9s) resetConnection(conn client.Connection) {
 	k.mx.Lock()
 	defer k.mx.Unlock()
@@ -72,17 +90,15 @@ func (k *K9s) resetConnection(conn client.Connection) {
 }
 
 // Save saves the k9s config to disk.
-func (k *K9s) Save(force bool) error {
-	if k.getActiveConfig() == nil {
-		log.Warn().Msgf("Save failed. no active config detected")
-		return nil
-	}
+func (k *K9s) Save(contextName, clusterName string, force bool) error {
 	path := filepath.Join(
 		AppContextsDir,
-		data.SanitizeContextSubpath(k.activeConfig.Context.GetClusterName(), k.getActiveContextName()),
+		data.SanitizeContextSubpath(clusterName, contextName),
 		data.MainConfigFile,
 	)
+
 	if _, err := os.Stat(path); errors.Is(err, fs.ErrNotExist) || force {
+		slog.Debug("[CONFIG] Saving context config to disk", slogs.Path, path, slogs.Cluster, k.getActiveConfig().Context.GetClusterName(), slogs.Context, k.getActiveContextName())
 		return k.dir.Save(path, k.getActiveConfig())
 	}
 
@@ -168,12 +184,9 @@ func (k *K9s) ActiveContext() (*data.Context, error) {
 	if cfg := k.getActiveConfig(); cfg != nil && cfg.Context != nil {
 		return cfg.Context, nil
 	}
-	ct, err := k.ActivateContext(k.getActiveContextName())
-	if err != nil {
-		return nil, err
-	}
+	ct, err := k.ActivateContext(k.ActiveContextName())
 
-	return ct, nil
+	return ct, err
 }
 
 func (k *K9s) setActiveConfig(c *data.Config) {
@@ -205,14 +218,14 @@ func (k *K9s) getActiveContextName() string {
 }
 
 // ActivateContext initializes the active context if not present.
-func (k *K9s) ActivateContext(n string) (*data.Context, error) {
-	k.setActiveContextName(n)
-	ct, err := k.ks.GetContext(n)
+func (k *K9s) ActivateContext(contextName string) (*data.Context, error) {
+	k.setActiveContextName(contextName)
+	ct, err := k.ks.GetContext(contextName)
 	if err != nil {
 		return nil, err
 	}
 
-	cfg, err := k.dir.Load(n, ct)
+	cfg, err := k.dir.Load(contextName, ct)
 	if err != nil {
 		return nil, err
 	}
@@ -220,7 +233,7 @@ func (k *K9s) ActivateContext(n string) (*data.Context, error) {
 
 	if cfg.Context.Proxy != nil {
 		k.ks.SetProxy(func(*http.Request) (*url.URL, error) {
-			log.Debug().Msgf("[Proxy]: %s", cfg.Context.Proxy.Address)
+			slog.Debug("Using proxy address", slogs.Address, cfg.Context.Proxy.Address)
 			return url.Parse(cfg.Context.Proxy.Address)
 		})
 
@@ -229,25 +242,25 @@ func (k *K9s) ActivateContext(n string) (*data.Context, error) {
 			// already has an API connection object so we just set the proxy to
 			// avoid recreation using client.InitConnection
 			k.conn.Config().SetProxy(func(*http.Request) (*url.URL, error) {
-				log.Debug().Msgf("[Proxy]: %s", cfg.Context.Proxy.Address)
+				slog.Debug("Setting proxy address", slogs.Address, cfg.Context.Proxy.Address)
 				return url.Parse(cfg.Context.Proxy.Address)
 			})
 
 			if !k.conn.CheckConnectivity() {
-				return nil, fmt.Errorf("unable to connect to context %q", n)
+				return nil, fmt.Errorf("unable to connect to context %q", contextName)
 			}
 		}
 	}
 
-	k.Validate(k.conn, k.ks)
+	k.Validate(k.conn, contextName, ct.Cluster)
 	// If the context specifies a namespace, use it!
 	if ns := ct.Namespace; ns != client.BlankNamespace {
 		k.getActiveConfig().Context.Namespace.Active = ns
-	} else if k.activeConfig.Context.Namespace.Active == "" {
+	} else if k.getActiveConfig().Context.Namespace.Active == "" {
 		k.getActiveConfig().Context.Namespace.Active = client.DefaultNamespace
 	}
 	if k.getActiveConfig().Context == nil {
-		return nil, fmt.Errorf("context activation failed for: %s", n)
+		return nil, fmt.Errorf("context activation failed for: %s", contextName)
 	}
 
 	return k.getActiveConfig().Context, nil
@@ -255,6 +268,10 @@ func (k *K9s) ActivateContext(n string) (*data.Context, error) {
 
 // Reload reloads the context config from disk.
 func (k *K9s) Reload() error {
+	// Switching context skipping reload...
+	if k.getContextSwitch() {
+		return nil
+	}
 	ct, err := k.ks.GetContext(k.getActiveContextName())
 	if err != nil {
 		return err
@@ -265,7 +282,7 @@ func (k *K9s) Reload() error {
 		return err
 	}
 	k.setActiveConfig(cfg)
-	k.getActiveConfig().Validate(k.conn, k.ks)
+	k.getActiveConfig().Validate(k.conn, k.getActiveContextName(), ct.Cluster)
 
 	return nil
 }
@@ -340,7 +357,7 @@ func (k *K9s) IsReadOnly() bool {
 }
 
 // Validate the current configuration.
-func (k *K9s) Validate(c client.Connection, ks data.KubeSettings) {
+func (k *K9s) Validate(c client.Connection, contextName, clusterName string) {
 	if k.RefreshRate <= 0 {
 		k.RefreshRate = defaultRefreshRate
 	}
@@ -348,16 +365,21 @@ func (k *K9s) Validate(c client.Connection, ks data.KubeSettings) {
 		k.MaxConnRetry = defaultMaxConnRetry
 	}
 
+	if a := os.Getenv(envPFAddress); a != "" {
+		k.PortForwardAddress = a
+	}
+	if k.PortForwardAddress == "" {
+		k.PortForwardAddress = defaultPFAddress()
+	}
+
 	if k.getActiveConfig() == nil {
-		if n, err := ks.CurrentContextName(); err == nil {
-			_, _ = k.ActivateContext(n)
-		}
+		_, _ = k.ActivateContext(contextName)
 	}
 	k.ShellPod = k.ShellPod.Validate()
 	k.Logger = k.Logger.Validate()
 	k.Thresholds = k.Thresholds.Validate()
 
 	if cfg := k.getActiveConfig(); cfg != nil {
-		cfg.Validate(c, ks)
+		cfg.Validate(c, contextName, clusterName)
 	}
 }
