@@ -6,22 +6,62 @@ package dao
 import (
 	"bytes"
 	"errors"
+	"fmt"
+	"log/slog"
 	"math"
-	"regexp"
 
-	"github.com/rs/zerolog/log"
+	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/slogs"
+	v1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/cli-runtime/pkg/printers"
 )
 
-const defaultServiceAccount = "default"
-
-var (
-	inverseRx = regexp.MustCompile(`\A\!`)
-	fuzzyRx   = regexp.MustCompile(`\A-f\s?([\w-]+)\b`)
+const (
+	defaultServiceAccount      = "default"
+	defaultContainerAnnotation = "kubectl.kubernetes.io/default-container"
 )
 
+// GetDefaultContainer returns a container name if specified in an annotation.
+func GetDefaultContainer(m metav1.ObjectMeta, spec v1.PodSpec) (string, bool) {
+	defaultContainer, ok := m.Annotations[defaultContainerAnnotation]
+	if !ok {
+		return "", false
+	}
+
+	for _, container := range spec.Containers {
+		if container.Name == defaultContainer {
+			return defaultContainer, true
+		}
+	}
+	slog.Warn("Container not found. Annotation ignored",
+		slogs.CO, defaultContainer,
+		slogs.Annotation, defaultContainerAnnotation,
+	)
+
+	return "", false
+}
+
+func extractFQN(o runtime.Object) string {
+	u, ok := o.(*unstructured.Unstructured)
+	if !ok {
+		slog.Error("Expecting unstructured", slogs.ResType, fmt.Sprintf("%T", o))
+		return client.NA
+	}
+
+	return FQN(u.GetNamespace(), u.GetName())
+}
+
+// FQN returns a fully qualified resource name.
+func FQN(ns, n string) string {
+	if ns == "" {
+		return n
+	}
+	return ns + "/" + n
+}
+
 func inList(ll []string, s string) bool {
 	for _, l := range ll {
 		if l == s {
@@ -31,24 +71,6 @@ func inList(ll []string, s string) bool {
 	return false
 }
 
-// IsInverseSelector checks if inverse char has been provided.
-func IsInverseSelector(s string) bool {
-	if s == "" {
-		return false
-	}
-	return inverseRx.MatchString(s)
-}
-
-// HasFuzzySelector checks if query is fuzzy.
-func HasFuzzySelector(s string) (string, bool) {
-	mm := fuzzyRx.FindStringSubmatch(s)
-	if len(mm) != 2 {
-		return "", false
-	}
-
-	return mm[1], true
-}
-
 func toPerc(v1, v2 float64) float64 {
 	if v2 == 0 {
 		return 0
@@ -75,7 +97,7 @@ func ToYAML(o runtime.Object, showManaged bool) (string, error) {
 	}
 	err := p.PrintObj(o, &buff)
 	if err != nil {
-		log.Error().Msgf("Marshal Error %v", err)
+		slog.Error("Marshal failed", slogs.Error, err)
 		return "", err
 	}
 
