@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/derailed/k9s/internal/model1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -37,31 +38,31 @@ type Rbac struct {
 }
 
 // ColorerFunc colors a resource row.
-func (Rbac) ColorerFunc() ColorerFunc {
-	return DefaultColorer
+func (Rbac) ColorerFunc() model1.ColorerFunc {
+	return model1.DefaultColorer
 }
 
 // Header returns a header row.
-func (Rbac) Header(ns string) Header {
-	h := make(Header, 0, 10)
+func (Rbac) Header(ns string) model1.Header {
+	h := make(model1.Header, 0, 10)
 	h = append(h,
-		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "API-GROUP"},
+		model1.HeaderColumn{Name: "NAME"},
+		model1.HeaderColumn{Name: "API-GROUP"},
 	)
 	h = append(h, rbacVerbHeader()...)
 
-	return append(h, HeaderColumn{Name: "VALID", Wide: true})
+	return append(h, model1.HeaderColumn{Name: "VALID", Attrs: model1.Attrs{Wide: true}})
 }
 
 // Render renders a K8s resource to screen.
-func (r Rbac) Render(o interface{}, ns string, ro *Row) error {
+func (r Rbac) Render(o interface{}, ns string, ro *model1.Row) error {
 	p, ok := o.(PolicyRes)
 	if !ok {
 		return fmt.Errorf("expecting RuleRes but got %T", o)
 	}
 
 	ro.ID = p.Resource
-	ro.Fields = make(Fields, 0, len(r.Header(ns)))
+	ro.Fields = make(model1.Fields, 0, len(r.Header(ns)))
 	ro.Fields = append(ro.Fields,
 		cleanseResource(p.Resource),
 		p.Group,
