@@ -77,7 +77,7 @@ func (h *Help) StylesChanged(s *config.Styles) {
 
 func (h *Help) bindKeys() {
 	h.Actions().Delete(ui.KeySpace, tcell.KeyCtrlSpace, tcell.KeyCtrlS, ui.KeySlash)
-	h.Actions().Set(ui.KeyActions{
+	h.Actions().Bulk(ui.KeyMap{
 		tcell.KeyEscape: ui.NewKeyAction("Back", h.app.PrevCmd, true),
 		ui.KeyHelp:      ui.NewKeyAction("Back", h.app.PrevCmd, false),
 		tcell.KeyEnter:  ui.NewKeyAction("Back", h.app.PrevCmd, false),
@@ -186,6 +186,18 @@ func (h *Help) showNav() model.MenuHints {
 			Mnemonic:    "j",
 			Description: "Down",
 		},
+		{
+			Mnemonic:    "[",
+			Description: "History Back",
+		},
+		{
+			Mnemonic:    "]",
+			Description: "History Forward",
+		},
+		{
+			Mnemonic:    "-",
+			Description: "Last Used Command",
+		},
 	}
 }
 
