@@ -6,16 +6,17 @@ package view
 import (
 	"context"
 	"fmt"
+	"log/slog"
 	"strconv"
 	"strings"
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model"
+	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
-	"github.com/rs/zerolog/log"
 	"github.com/sahilm/fuzzy"
 )
 
@@ -233,12 +234,12 @@ func (v *LiveView) Start() {
 		ctx, v.cancel = context.WithCancel(v.defaultCtx())
 
 		if err := v.model.Watch(ctx); err != nil {
-			log.Error().Err(err).Msgf("LiveView watcher failed")
+			slog.Error("LiveView watcher failed", slogs.Error, err)
 		}
 		return
 	}
 	if err := v.model.Refresh(v.defaultCtx()); err != nil {
-		log.Error().Err(err).Msgf("refresh failed")
+		slog.Error("LiveView refresh failed", slogs.Error, err)
 	}
 }
 
