@@ -1,10 +1,14 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package watch
 
 import (
+	"fmt"
+	"log/slog"
 	"path"
 	"strings"
 
-	"github.com/rs/zerolog/log"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
 
@@ -29,22 +33,22 @@ func namespaced(n string) (string, string) {
 
 // DumpFactory for debug.
 func DumpFactory(f *Factory) {
-	log.Debug().Msgf("----------- FACTORIES -------------")
+	slog.Debug("----------- FACTORIES -------------")
 	for ns := range f.factories {
-		log.Debug().Msgf("  Factory for NS %q", ns)
+		slog.Debug(fmt.Sprintf("  Factory for NS %q", ns))
 	}
-	log.Debug().Msgf("-----------------------------------")
+	slog.Debug("-----------------------------------")
 }
 
 // DebugFactory for debug.
 func DebugFactory(f *Factory, ns string, gvr string) {
-	log.Debug().Msgf("----------- DEBUG FACTORY (%s) -------------", gvr)
+	slog.Debug(fmt.Sprintf("----------- DEBUG FACTORY (%s) -------------", gvr))
 	fac, ok := f.factories[ns]
 	if !ok {
 		return
 	}
 	inf := fac.ForResource(toGVR(gvr))
 	for i, k := range inf.Informer().GetStore().ListKeys() {
-		log.Debug().Msgf("%d -- %s", i, k)
+		slog.Debug(fmt.Sprintf("%d -- %s", i, k))
 	}
 }
